@@ -2,7 +2,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "memory.h"
+#include "cow.h"
 
 gint total_len = 30000;
 gint loop_len = 1000;
